pub struct ContractFactSet<'tcx> {
pub contracts: Vec<PropertyContract<'tcx>>,
pub predicates: Vec<NumericPredicate<'tcx>>,
}Expand description
The set of contract facts known to hold for one graph node.
Fields
contracts: Vec<PropertyContract<'tcx>>predicates: Vec<NumericPredicate<'tcx>>Implementations
Sourceimpl<'tcx> ContractFactSet<'tcx>
impl<'tcx> ContractFactSet<'tcx>
Sourcepub fn new_default() -> Self
pub fn new_default() -> Self
Create an empty contract fact set.
Sourcepub fn add_contract(&mut self, contract: PropertyContract<'tcx>)
pub fn add_contract(&mut self, contract: PropertyContract<'tcx>)
Add one contract assumption to the fact set.
Sourcepub fn add_predicate(&mut self, predicate: NumericPredicate<'tcx>)
pub fn add_predicate(&mut self, predicate: NumericPredicate<'tcx>)
Add one numeric predicate to the fact set.
Sourcepub fn get_contracts_length(&self) -> usize
pub fn get_contracts_length(&self) -> usize
Return the number of contract entries stored in the fact set.